@@ -25,7 +25,7 @@
     } else if (is.factor(x)) {
       fun <- fun[which(fnames %in% c("factor", "f"))]
       if (!fun %in% c("mode", "reference")) {
-        insight::format_alert("Function for typical value for factors must be either `mode` or `reference`. Using `reference` as function for typical value.")
+        insight::format_alert("Function for typical value for factors must be either `mode` or `reference`. Using `reference` as function for typical value.") # nolint
         fun <- "reference"
       }
     }
@@ -37,7 +37,7 @@
     # make sure weights and x have same length
     if (length(weights) != length(x)) {
       # if not, tell user and change function to mean
-      insight::format_alert("Vector of weights is of different length than `x`. Using `mean` as function for typical value.")
+      insight::format_alert("Vector of weights is of different length than `x`. Using `mean` as function for typical value.") # nolint
       fun <- "mean"
     }
     # make sure weights are different from 1
@@ -51,17 +51,16 @@
   # no weights, than use normal mean function
   if (fun == "weighted.mean" && is.null(weights)) fun <- "mean"
 
-  if (fun == "median") {
-    myfun <- get("median", asNamespace("stats"))
-  } else if (fun == "weighted.mean") {
-    myfun <- get("weighted.mean", asNamespace("stats"))
-  } else if (fun == "mode") {
-    myfun <- get(".mode_value", asNamespace("ggeffects"))
-  } else if (fun == "zero") {
-    return(0)
-  } else {
-    myfun <- get("mean", asNamespace("base"))
-  }
+  # return 0 if "fun" is "zero"
+  if (fun == "zero") return(0)
+
+  myfun <- switch(fun,
+    mean = get("mean", asNamespace("base")),
+    median = get("median", asNamespace("stats")),
+    weighted.mean = get("weighted.mean", asNamespace("stats")),
+    mode = get(".mode_value", asNamespace("ggeffects")),
+    get("mean", asNamespace("base"))
+  )
 
   if (is.integer(x)) {
     out <- stats::median(x, na.rm = TRUE)
@@ -99,9 +98,9 @@
   idx <- which.max(tab)
   modus <- uniqv[idx]
   # check if it's numeric
-  if (!is.numeric(modus)) {
-    as.character(modus)
-  } else {
+  if (is.numeric(modus)) {
     modus
+  } else {
+    as.character(modus)
   }
 }
